@@ -28,10 +28,12 @@ class COCOMetric(Metric):
     def __init__(
         self,
         metric_type: COCOMetricType = COCOMetricType.bbox,
+        iou_thresholds: Optional[Sequence[float]] = None,
         print_summary: bool = False,
         show_pbar: bool = False,
     ):
         self.metric_type = metric_type
+        self.iou_thresholds = iou_thresholds
         self.print_summary = print_summary
         self.show_pbar = show_pbar
         self._records, self._preds = [], []
@@ -40,9 +42,10 @@ class COCOMetric(Metric):
         self._records.clear()
         self._preds.clear()
 
-    def accumulate(self, records, preds):
-        self._records.extend(records)
-        self._preds.extend(preds)
+    def accumulate(self, preds):
+        for pred in preds:
+            self._records.append(pred.ground_truth)
+            self._preds.append(pred.pred)
 
     def finalize(self) -> Dict[str, float]:
         with CaptureStdout():
@@ -50,6 +53,7 @@ class COCOMetric(Metric):
                 records=self._records,
                 preds=self._preds,
                 metric_type=self.metric_type.value,
+                iou_thresholds=self.iou_thresholds,
                 show_pbar=self.show_pbar,
             )
             coco_eval.evaluate()
