@@ -13,6 +13,7 @@ from icevision.models.mmdet.download_configs import download_mmdet_configs
 from mmdet.models.detectors import *
 from mmcv import Config
 from mmdet.models.backbones.ssd_vgg import SSDVGG
+from mmdet.models.backbones.csp_darknet import CSPDarknet
 
 
 mmdet_configs_path = download_mmdet_configs()
@@ -37,6 +38,10 @@ def param_groups(model):
     if isinstance(body, SSDVGG):
         layers += [body.features]
         layers += [body.extra, body.l2_norm]
+    elif isinstance(body, CSPDarknet):
+        layers += [body.stem.conv.conv, body.stem.conv.bn]
+        layers += [body.stage1, body.stage2, body.stage3, body.stage4]
+        layers += [model.neck]
     else:
         layers += [nn.Sequential(body.conv1, body.bn1)]
         layers += [getattr(body, l) for l in body.res_layers]
@@ -61,6 +66,7 @@ def create_model_config(
     pretrained: bool = True,
     checkpoints_path: Optional[Union[str, Path]] = "checkpoints",
     force_download=False,
+    cfg_options=None,
 ):
 
     model_name = backbone.model_name
@@ -68,6 +74,7 @@ def create_model_config(
     weights_url = backbone.weights_url
 
     # download weights
+    weights_path = None
     if pretrained and weights_url:
         save_dir = Path(checkpoints_path) / model_name
         save_dir.mkdir(exist_ok=True, parents=True)
@@ -80,4 +87,7 @@ def create_model_config(
 
     cfg = Config.fromfile(config_path)
 
+    if cfg_options is not None:
+        cfg.merge_from_dict(cfg_options)
+
     return cfg, weights_path
