@@ -1,6 +1,4 @@
-from icevision.parsers.mixins import *
 from icevision.parsers.parser import *
-from icevision.parsers.defaults import *
 
 from icevision.parsers.coco_parser import *
 from icevision.parsers.voc_parser import *
