@@ -22,6 +22,9 @@ class _SoftDependencies:
         self.effdet = soft_import("effdet")
         self.wandb = soft_import("wandb")
         self.resnest = soft_import("resnest")
+        self.mmdet = soft_import("mmdet")
+        self.yolov5 = soft_import("yolov5")
+        self.sklearn = soft_import("sklearn")
 
     def check(self) -> Dict[str, bool]:
         return self.__dict__.copy()
