@@ -14,6 +14,7 @@ __all__ = [
     "denormalize",
     "normalize_imagenet",
     "denormalize_imagenet",
+    "denormalize_mask",
     "patch_class_to_main",
 ]
 
@@ -58,8 +59,8 @@ def zipsafe(*its):
     return zip(*its)
 
 
-def pbar(iter, show=True):
-    return tqdm(iter) if show else iter
+def pbar(iter, show=True, total: Optional[int] = None):
+    return tqdm(iter, total=total) if show else iter
 
 
 @contextmanager
@@ -97,6 +98,11 @@ def normalize_imagenet(img):
     return normalize(img=img, mean=mean, std=std)
 
 
+def denormalize_mask(img):
+    mean, std = [0, 0, 0], [0, 0, 0]
+    return denormalize(img=img, mean=mean, std=std)
+
+
 def patch_class_to_main(cls):
     import __main__
 
